.. _index:

Qpimage is a Python library that provides a convenient interface
to many common functionalities that are used in quantitative
phase imaging. This is the documentation of qpimage version |release|.


Documentation
=============

.. toctree::
   :maxdepth: 4

   sec_introduction
   sec_getting_started
   sec_examples
   sec_format
   sec_code_reference

.. toctree::
   :maxdepth: 1

   sec_changelog
   sec_z_bib


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
